<?php

/**
 * @file
 * Contains Views Row Insert style plugin.
 */

/**
 * Defines a style plugin that adds custom row after every nth view rows.
 *
 * @ingroup views_style_plugins
 */
class views_row_insert_plugin_style_custom_row extends views_plugin_style {

  /**
   * Overrides views_plugin_style::options_definition().
   */
  function option_definition() {
    $options = parent::option_definition();
    $options['use_plugin'] = ['default' => '1'];
    $options['data_mode'] = ['default' => 'block'];
    $options['rows_number'] = ['default' => '1'];
    $options['class_name'] = ['default' => ''];
    $options['block_name'] = ['default' => ''];
    $options['exclude_classes'] = ['default' => 0];
    $options['custom_row_data'] = ['default' => ''];
    $options['show_method'] = ['default' => '0'];
    $options['default_rows'] = ['default' => '1'];
    $options['strip_rows'] = ['default' => '1'];
    return $options;
  }

  /**
   * Overrides views_plugin_style::options_form().
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    $form['use_plugin'] = [
      '#type' => 'checkbox',
      '#title' => t('Use this plugin'),
      '#default_value' => $this->options['use_plugin'],
      '#description' => t('Check if you want to use this plugin.'),
    ];
    $form['data_mode'] = [
      '#type' => 'radios',
      '#title' => t('Row type'),
      '#options' => ['block' => 'Block', 'text' => 'Custom content'],
      '#default_value' => $this->options['data_mode'],
    ];
    $blocks = _views_row_insert_get_blocks();
    $form['block_name'] = [
      '#type' => 'select',
      '#title' => t('Select a block'),
      '#options' => $blocks,
      '#default_value' => $this->options['block_name'],
      '#description' => t('Select a block to insert instead of using custom content.'),
    ];
    $form['custom_row_data'] = [
      '#type' => 'textarea',
      '#title' => t('Custom content'),
      '#default_value' => $this->options['custom_row_data'],
      '#description' => t('Enter text or html code.'),
    ];
    $rows_num = [0 => t('Each')];
    $k = 1;
    while ($k < 100) {
      $rows_num[$k] = $k + 1;
      $k ++;
    }
    $form['rows_number'] = [
      '#type' => 'select',
      '#title' => t('Insert after every Nth row'),
      '#options' => $rows_num,
      '#default_value' => $this->options['rows_number'],
      '#description' => t('Number of rows to skip.'),
    ];
    $form['show_method'] = [
      '#type' => 'checkbox',
      '#title' => t('Show once (skip first N rows only)'),
      '#default_value' => $this->options['show_method'],
      '#description' => t('Check if you want to display this row only one time per page.'),
    ];
    $form['class_name'] = [
      '#title' => t('Row class name(s)'),
      '#type' => 'textfield',
      '#default_value' => $this->options['class_name'],
    ];
    $form['default_rows'] = [
      '#type' => 'checkbox',
      '#title' => t('Add views row classes'),
      '#default_value' => $this->options['default_rows'],
      '#description' => t('Add the default row classes like views-row-1 to the output. You can use this to quickly reduce the amount of markup the view provides by default, at the cost of making it more difficult to apply CSS.'),
    ];
    $form['strip_rows'] = [
      '#type' => 'checkbox',
      '#title' => t('Add striping (odd/even), first/last row classes'),
      '#default_value' => $this->options['strip_rows'],
      '#description' => t('Add css classes to the first and last line, as well as odd/even classes for striping.'),
    ];
    $form['exclude_classes'] = [
      '#type' => 'checkbox',
      '#title' => t('Do not apply the default classes to created row'),
      '#default_value' => $this->options['exclude_classes'],
      '#description' => t('Check if you want to exclude the default row classes and striping (odd/even), first/last classes from adding to this row.'),
    ];
    $form['#attached']['js'] = [
      drupal_get_path('module', 'views_row_insert') . '/js/helper.js',
    ];
    $form['#attached']['js'][] = [
      'type' => 'setting',
      'data' => ['views_row_insert' => ['data_mode' => $this->options['data_mode']]],
    ];
  }
}
